<?php
namespace Aws\VerifiedPermissions\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Amazon Verified Permissions** service.
 */
class VerifiedPermissionsException extends AwsException {}
